==> acoupi-0.1.0.tar.gz: acoupi-0.1.0/docs/howtoguide/index.md <==
# How-To Guides

Welcome to the _How-To Guides Section_ of _acoupi_.

This section of the documentation is intended for users who are already familiar with _acoupi_, and need to create new _acoupi_ elements to meet their requirements.
The _How-To Guide_ have more in-depth detail information than the tutorials and should help users create acoupi elements for their specific use cases.

<div class="md-table">
  <table>
    <thead>
      <tr>
        <th>
          <strong>How-To Guides</strong>
        </th>
        <th>Get Stuff Done</th>
      </tr>
    </thead>
    <tbody>
      <tr>
        <td>
          <a href="Programs">Create custom programs</a>
        </td>
        <td>Learn how to create a custom program</td>
      </tr>
      <tr>
        <td>
          <a href="Components">Create new components</a>
        </td>
        <td>Learn how to create new components</td>
      </tr>
      <tr>
      <tr>
        <td>
          <a href="Data_Schema">Create new data objects</a>
        </td>
        <td>Learn how to create new data objects</td>
      </tr>
    </tbody>
  </table>
</div>

!!! info "New to _acoupi_?"

    If you want to get started with _acoupi_, look at the [_Tutorials_](../tutorials/index.md) section providing step-by-step information to help you install, configure, and deploy _acoupi_.

!!! info "How _acoupi_ works"

    To get a better understanding of the key elements of acoupi have a read at the [_Explanation_](../explanation/index.md) section of the documentation.
    Illustrations and examples should provide you with easy-to-follow descriptions about the structure of the code.

!!! info "_acoupi_ Reference"

    Take a look at the [_Reference_](../reference/index.md) section of the documentation to know which options are available and can be used "out-of the box".

!!! tip "Suggest a How-To Guide"

    We are interested to expand the number of how-to guides so users can gain more detailed information about specific elements of acoupi. If you feel we should do a how-to guide about "XYZ", please reach out!

==> acoupi-0.3.0.tar.gz: acoupi-0.3.0/docs/howtoguide/index.md <==
# How-To Guides

Welcome to the _How-To Guides Section_ of _acoupi_.

This section of the documentation is intended for users who are already familiar with _acoupi_, and need to create new _acoupi_ elements to meet their requirements.
The _How-To Guide_ have more in-depth detail information than the tutorials and should help users create acoupi elements for their specific use cases.

<div class="md-table">
  <table>
    <thead>
      <tr>
        <th>
          <strong>How-To Guides</strong>
        </th>
        <th>Get Stuff Done</th>
      </tr>
    </thead>
    <tbody>
      <tr>
        <td>
          <a href="programs">Create custom programs</a>
        </td>
        <td>Learn how to create a custom program</td>
      </tr>
      <tr>
        <td>
          <a href="components">Create new components</a>
        </td>
        <td>Learn how to create new components</td>
      </tr>
      <tr>
      <tr>
        <td>
          <a href="data_schema">Create new data objects</a>
        </td>
        <td>Learn how to create new data objects</td>
      </tr>
    </tbody>
  </table>
</div>

!!! info "New to _acoupi_?"

    If you want to get started with _acoupi_, look at the [_Tutorials_](../tutorials/index.md) section providing step-by-step information to help you install, configure, and deploy _acoupi_.

!!! info "How _acoupi_ works"

    To get a better understanding of the key elements of acoupi have a read at the [_Explanation_](../explanation/index.md) section of the documentation.
    Illustrations and examples should provide you with easy-to-follow descriptions about the structure of the code.

!!! info "_acoupi_ Reference"

    Take a look at the [_Reference_](../reference/index.md) section of the documentation to know which options are available and can be used "out-of the box".

!!! tip "Suggest a How-To Guide"

    We are interested to expand the number of how-to guides so users can gain more detailed information about specific elements of acoupi. If you feel we should do a how-to guide about "XYZ", please reach out!
